@@ -16,9 +16,12 @@
 
 """Dependency Management APIs for jupyter server."""
 
+from .api import YamlSpecHandler
+from .base import DependencyManagementBaseHandler
 from .dependencies_files_handler import DependenciesFilesHandler
 from .discover_handler import DependencyInstalledHandler
 from .discover_handler import PythonVersionHandler
+from .discover_handler import RootPathHandler
 from .kernel_handler import JupyterKernelHandler
 from .install_handler import DependencyInstallHandler
 from .pipenv import PipenvHandler
@@ -27,13 +30,16 @@ from .thoth_config_handler import ThothConfigHandler
 from .thoth_invectio import ThothInvectioHandler
 
 __all__ = [
+    "DependencyManagementBaseHandler",
     "DependenciesFilesHandler",
     "DependencyInstallHandler",
     "DependencyInstalledHandler",
     "JupyterKernelHandler",
     "PipenvHandler",
     "PythonVersionHandler",
+    "RootPathHandler",
     "ThothAdviseHandler",
     "ThothConfigHandler",
-    "ThothInvectioHandler"
+    "ThothInvectioHandler",
+    "YamlSpecHandler",
 ]
