@@ -16,7 +16,6 @@
 
 """Install API for jupyterlab requirements."""
 
-import json
 import os
 import subprocess
 import logging
@@ -24,20 +23,27 @@ from virtualenv import cli_run
 
 from pathlib import Path
 
-from jupyter_server.base.handlers import APIHandler
+from jupyterlab_requirements.dependency_management.base import DependencyManagementBaseHandler
 from tornado import web
 
 _LOGGER = logging.getLogger("jupyterlab_requirements.install_handler")
 
 
-class DependencyInstallHandler(APIHandler):
+class DependencyInstallHandler(DependencyManagementBaseHandler):
     """Dependency management handler to install dependencies."""
 
     @web.authenticated
     def post(self):
+        """Post method for class."""
+        input_data = self.get_json_body()
+
+        task_index = self._tasks.create_task(self.install_dependencies, input_data)
+
+        self.redirect_to_task(task_index)
+
+    async def install_dependencies(self, input_data):
         """Install packages using selected package manager."""
         initial_path = Path.cwd()
-        input_data = self.get_json_body()
         kernel_name: str = input_data["kernel_name"]
         resolution_engine: str = input_data["resolution_engine"]
         _LOGGER.info(f"kernel_name selected: {kernel_name}")
@@ -52,22 +58,24 @@ class DependencyInstallHandler(APIHandler):
 
         os.chdir(complete_path)
 
-        package_manager: str = 'micropipenv'
+        package_manager: str = "micropipenv"
 
-        _LOGGER.info(f"Installing requirements using {package_manager} in virtualenv at {env_path}." )
+        _LOGGER.info(f"Installing requirements using {package_manager} in virtualenv at {env_path}.")
 
-        #1. Creating new environment
+        # 1. Creating new environment
         if resolution_engine != "pipenv":
             cli_run([str(env_path)])
 
         # TODO: Check if micropipenv is installed
-        #2. Install using micropipenv
+        # 2. Install using micropipenv
         _ = subprocess.call(
-            f". {kernel_name}/bin/activate "
-            f"&& cd {kernel_name} && micropipenv install --dev", shell=True, cwd=complete_path)
+            f". {kernel_name}/bin/activate " f"&& cd {kernel_name} && micropipenv install --dev",
+            shell=True,
+            cwd=complete_path,
+        )
 
         os.chdir(initial_path)
-        self.finish(json.dumps({
-            "message": "installed with micropipenv",
-            "kernel_name": env_name
-        }))
+
+        result = {"message": "installed with micropipenv", "kernel_name": env_name, "error": False}
+
+        return 0, result
