@@ -19,12 +19,11 @@
 import json
 import os
 import logging
-import subprocess
 import tempfile
 
 from pathlib import Path
 
-from jupyter_server.base.handlers import APIHandler
+from jupyterlab_requirements.dependency_management.base import DependencyManagementBaseHandler
 from tornado import web
 
 from thamos.lib import advise_using_config, _get_origin
@@ -35,14 +34,21 @@ from thoth.common import ThothAdviserIntegrationEnum
 _LOGGER = logging.getLogger("jupyterlab_requirements.thoth")
 
 
-class ThothAdviseHandler(APIHandler):
+class ThothAdviseHandler(DependencyManagementBaseHandler):
     """Thoth handler to receive optimized software stack."""
 
     @web.authenticated
-    async def post(self):
+    def post(self):
+        """Post method for class."""
+        input_data = self.get_json_body()
+
+        task_index = self._tasks.create_task(self.lock_using_thoth, input_data)
+
+        self.redirect_to_task(task_index)
+
+    async def lock_using_thoth(self, input_data):
         """Lock dependencies using Thoth service."""
         initial_path = Path.cwd()
-        input_data = self.get_json_body()
 
         config: str = input_data["thoth_config"]
         kernel_name: str = input_data["kernel_name"]
@@ -58,30 +64,22 @@ class ThothAdviseHandler(APIHandler):
         complete_path = home.joinpath(".local/share/thoth/kernels")
         env_path = complete_path.joinpath(kernel_name)
 
-        # Delete and recreate folder
-        if not env_path.exists():
-            _ = subprocess.call(
-                f"rm -rf ./{kernel_name} ", shell=True, cwd=complete_path)
-
         env_path.mkdir(parents=True, exist_ok=True)
         os.chdir(env_path)
 
         _LOGGER.info("Resolution engine used: thoth")
         pipfile_string = Pipfile.from_dict(requirements).to_string()
 
-        _LOGGER.info(f"Current path: %r ", env_path.as_posix())
+        _LOGGER.info("Current path: %r ", env_path.as_posix())
         _LOGGER.info(f"Input Pipfile: \n{pipfile_string}")
 
-        advise = {"requirements": {}, "requirement_lock": {}, "error": False}
+        advise = {"requirements": {}, "requirement_lock": {}, "error": False, "error_msg": ""}
+        returncode = 0
 
-        temp = tempfile.NamedTemporaryFile(prefix="jl_thoth_", mode='w+t')
+        temp = tempfile.NamedTemporaryFile(prefix="jl_thoth_", mode="w+t")
 
         try:
-            adviser_inputs = {
-                "pipfile": pipfile_string,
-                "config": config,
-                "origin": origin
-            }
+            adviser_inputs = {"pipfile": pipfile_string, "config": config, "origin": origin}
             _LOGGER.info("Adviser inputs are: %r", adviser_inputs)
 
             temp.write(notebook_content)
@@ -97,7 +95,7 @@ class ThothAdviseHandler(APIHandler):
                 source_type=ThothAdviserIntegrationEnum.JUPYTER_NOTEBOOK,
                 no_static_analysis=False,
                 timeout=timeout,
-                src_path=temp.name
+                src_path=temp.name,
             )
 
             _LOGGER.info(f"Response: {response}")
@@ -108,7 +106,9 @@ class ThothAdviseHandler(APIHandler):
             result, error_result = response
 
             if error_result:
-                advise['error'] = True
+                advise["error"] = True
+                advise["error_msg"] = error_result
+                returncode = 1
 
             else:
                 # Use report of the best one, therefore index 0
@@ -120,21 +120,22 @@ class ThothAdviseHandler(APIHandler):
                     _LOGGER.debug(f"Stack info {stack_info}")
 
                     pipfile = result["report"]["products"][0]["project"]["requirements"]
-                    pipfile_lock = result["report"]["products"][0]["project"][
-                        "requirements_locked"
-                    ]
+                    pipfile_lock = result["report"]["products"][0]["project"]["requirements_locked"]
 
                     advise = {"requirements": pipfile, "requirement_lock": pipfile_lock, "error": False}
 
         except Exception as api_error:
             _LOGGER.warning(f"error locking dependencies using Thoth: {api_error}")
-            advise['error'] = True
+            advise["error"] = True
+            advise["error_msg"] = "Error locking dependencies, check pod logs for more details about the error."
+            returncode = 1
+
         finally:
             temp.close()
 
         _LOGGER.info(f"advise received: {advise}")
 
-        if not advise['error']:
+        if not advise["error"]:
             try:
                 requirements_format = "pipenv"
 
@@ -145,12 +146,10 @@ class ThothAdviseHandler(APIHandler):
 
                 if requirements_format == "pipenv":
                     _LOGGER.info("Writing to Pipfile/Pipfile.lock in %r", env_path.as_posix())
-                    project.to_files(
-                        pipfile_path=pipfile_path,
-                        pipfile_lock_path=pipfile_lock_path
-                    )
+                    project.to_files(pipfile_path=pipfile_path, pipfile_lock_path=pipfile_lock_path)
             except Exception as e:
                 _LOGGER.warning("Requirements files have not been stored successfully %r", e)
 
         os.chdir(initial_path)
-        self.finish(json.dumps(advise))
+
+        return returncode, advise
