@@ -27,7 +27,8 @@ import { ThothConfig } from '../types/thoth';
 
 import {
   install_packages,
-  create_new_kernel
+  create_new_kernel,
+  discover_root_directory
 } from '../kernel';
 
 import {
@@ -36,6 +37,8 @@ import {
   lock_requirements_with_pipenv
 } from '../thoth';
 
+// import { INotification } from 'jupyterlab_toastify';
+
 import {
   get_kernel_name
 } from "../notebook"
@@ -90,7 +93,9 @@ export interface IDependencyManagementUIState {
   thoth_config: ThothConfig,
   error_msg: string,
   resolution_engine: string,
-  thoth_timeout: number
+  thoth_timeout: number,
+  isEditing: boolean,
+  root_directory: string
 }
 
 /**
@@ -103,26 +108,6 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
     ) {
       super(props);
 
-      this.onStart = this.onStart.bind(this),
-      this.execute_code_in_kernel = this.execute_code_in_kernel.bind(this),
-      this.changeUIstate = this.changeUIstate.bind(this),
-      this.addNewRow = this.addNewRow.bind(this),
-      this.editRow = this.editRow.bind(this),
-      this.editSavedRow = this.editSavedRow.bind(this),
-      this.storeRow = this.storeRow.bind(this),
-      this.deleteRow = this.deleteRow.bind(this),
-      this.deleteSavedRow = this.deleteSavedRow.bind(this),
-      this.onSave = this.onSave.bind(this),
-      this.lock_using_thoth = this.lock_using_thoth.bind(this),
-      this.lock_using_pipenv = this.lock_using_pipenv.bind(this),
-      this.install = this.install.bind(this),
-      this.setKernel = this.setKernel.bind(this),
-      this.setKernelName = this.setKernelName.bind(this)
-      this.setRecommendationType = this.setRecommendationType.bind(this)
-      this.setTimeout = this.setTimeout.bind(this)
-
-      this._model = new KernelModel ( this.props.panel.sessionContext )
-
       this.state = {
         kernel_name: get_kernel_name( this.props.panel ),
         recommendation_type: "latest",
@@ -152,12 +137,35 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
             },
             python_version: "3.8",
             recommendation_type: "latest"
-        }]
+          }]
         },
         error_msg: undefined,
         resolution_engine: "thoth",
-        thoth_timeout: 60
+        thoth_timeout: 180,
+        isEditing: false,
+        root_directory: ""
       }
+
+      this.onStart = this.onStart.bind(this),
+      this.execute_code_in_kernel = this.execute_code_in_kernel.bind(this),
+      this.changeUIstate = this.changeUIstate.bind(this),
+      this.addNewRow = this.addNewRow.bind(this),
+      this.editRow = this.editRow.bind(this),
+      this.editSavedRow = this.editSavedRow.bind(this),
+      this.storeRow = this.storeRow.bind(this),
+      this.deleteRow = this.deleteRow.bind(this),
+      this.deleteSavedRow = this.deleteSavedRow.bind(this),
+      this.onSave = this.onSave.bind(this),
+      this.lock_using_thoth = this.lock_using_thoth.bind(this),
+      this.lock_using_pipenv = this.lock_using_pipenv.bind(this),
+      this.install = this.install.bind(this),
+      this.setKernel = this.setKernel.bind(this),
+      this.setKernelName = this.setKernelName.bind(this)
+      this.setRecommendationType = this.setRecommendationType.bind(this)
+      this.setTimeout = this.setTimeout.bind(this)
+      this.setRootDirectoryPath = this.setRootDirectoryPath.bind(this)
+
+      this._model = new KernelModel ( this.props.panel.sessionContext )
     }
 
     /**
@@ -224,6 +232,25 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
 
     }
 
+    /**
+     * Function: Set root directory where to place overlays and where to find .thoth.yaml
+     */
+
+     setRootDirectoryPath(event: React.ChangeEvent<HTMLInputElement>) {
+
+      var root_directory = event.target.value
+
+      // TODO: Check if Path exists!
+
+      this.setState(
+        {
+          root_directory: root_directory
+        }
+      );
+
+    }
+
+
     /**
      * Function: Set recommendation type for thamos advise
      */
@@ -317,8 +344,12 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
     editRow(package_name: string) {
 
       const packages = this.state.packages
+      const loaded_packages = this.state.loaded_packages
+      const installed_packages = this.state.installed_packages
 
       _.unset(packages, package_name)
+      _.unset(loaded_packages, package_name)
+      _.unset(installed_packages, package_name)
       _.set(packages, "", "*")
 
       console.debug("After editing (current)", packages)
@@ -326,8 +357,8 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
       this.changeUIstate(
         "editing",
         packages,
-        this.state.loaded_packages,
-        this.state.installed_packages,
+        loaded_packages,
+        installed_packages,
         this.state.deleted_packages,
         this.state.requirements,
         this.state.kernel_name,
@@ -344,9 +375,12 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
 
       const loaded_packages = this.state.loaded_packages
       const packages = this.state.packages
+      const installed_packages = this.state.installed_packages
 
+      _.unset(packages, package_name)
       _.unset(loaded_packages, package_name)
-      _.set(packages, package_name, package_version)
+      _.unset(installed_packages, package_name)
+      _.set(packages, "", "*")
 
       console.debug("After editing (initial)", loaded_packages)
       console.debug("After editing (current)", packages)
@@ -355,7 +389,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
         "editing",
         packages,
         loaded_packages,
-        this.state.installed_packages,
+        installed_packages,
         this.state.deleted_packages,
         this.state.requirements,
         this.state.kernel_name,
@@ -580,7 +614,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
 
       try {
 
-        var advise: Advise = await lock_requirements_with_thoth(
+        var advise: Advise | undefined = await lock_requirements_with_thoth(
           this.state.kernel_name,
           this.state.thoth_timeout,
           notebook_content,
@@ -597,7 +631,10 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
         return
       }
 
-      if ( advise.error == true ) {
+      if ( advise == undefined || advise.error == true ) {
+        if ( advise != undefined ) {
+          console.log("Thoth resolution engine error:", advise.error_msg)
+        }
         _.set(ui_state, "resolution_engine", "pipenv" )
         _.set(ui_state, "status", "locking_requirements_using_pipenv")
         await this.setNewState(ui_state);
@@ -624,7 +661,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
           advise.requirements,
           advise.requirement_lock,
           'overlays',
-          false
+          this.state.root_directory
         )
       } catch ( error ) {
 
@@ -635,7 +672,8 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
       try {
         await update_thoth_config_on_disk(
           this.state.thoth_config.runtime_environments[0],
-          true
+          true,
+          this.state.root_directory
           )
         } catch ( error ) {
         console.debug("Error updating thoth config on disk", error)
@@ -677,7 +715,11 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
         return
       }
 
-      if ( result.error == true ) {
+      if ( result == undefined || result.error == true ) {
+
+        if ( result != undefined ) {
+          console.log("Pipenv resolution engine error:", result.error_msg)
+        }
         _.set(ui_state, "status", "failed")
         _.set(
           ui_state,
@@ -708,7 +750,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
           notebookMetadataRequirements,
           result.requirements_lock,
           'overlays',
-          false
+          this.state.root_directory
         )
 
       } catch ( error ) {
@@ -732,6 +774,8 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
       // `
       // await this.execute_code_in_kernel(script)
 
+      const root_directory = await discover_root_directory()
+
       var ui_on_start_state = await parse_inputs_from_metadata(
         this.state,
         this.props.panel,
@@ -741,6 +785,8 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
         this.props.loaded_resolution_engine
       )
 
+      _.set(ui_on_start_state, "root_directory", root_directory)
+
       await this.setNewState(ui_on_start_state);
       return
     }
@@ -807,6 +853,17 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
                               />
                             </label>
                             <br />
+                            <label>
+                              Path root project:
+                              <input
+                                title="Path root project"
+                                type="text"
+                                name="root_directory"
+                                value={this.state.root_directory}
+                                onChange={this.setRootDirectoryPath}
+                              />
+                            </label>
+                            <br />
                             <label>
                               Recommendation type:
                               <select onChange={() => this.changeRecommendationType}>
@@ -950,7 +1007,6 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
             </div>
           );
 
-
         case "saved":
           return (
             <div>
@@ -1075,7 +1131,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
               <div>
                 <p>{this.state.error_msg}</p>
               </div>
-              <a href={"https://github.com/thoth-station/core/issues/new?assignees=&labels=&template=bug_report.md"} target="_blank"> Open Issue </a>
+              <a href={"https://github.com/thoth-station/jupyterlab-requirements/issues/new?assignees=&labels=bug&template=bug_report.md"} target="_blank"> Open Issue </a>
             </div>
         );
 
@@ -1097,7 +1153,7 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
             </div>
           );
 
-          case "stable_no_runenv":
+        case "stable_no_runenv":
             // TODO: Provide relock button option if the resolution engine is different from thoth
             return (
               <div>
@@ -1118,12 +1174,12 @@ export class DependenciesManagementUI extends React.Component<IDependencyManagem
             </div>
             );
 
-        case"ready":
+        case "ready":
 
           // Check if kernel name is already assigned to notebook and if yes, do nothing
-
-          if ( get_kernel_name( this.props.panel ) == this.state.kernel_name ) {
-            console.log("kernel name already set for the notebook, do not restart kernel...")
+          const current_kernel = get_kernel_name( this.props.panel, true )
+          if ( current_kernel == this.state.kernel_name ) {
+            console.log("kernel name to be assigned " + this.state.kernel_name + " already set for the notebook " + current_kernel + ", do not restart kernel...")
           }
           else {
             this.props.panel.sessionContext.session.changeKernel({"name": this.state.kernel_name})
