@@ -239,6 +239,14 @@ export async function _handle_requirements(
                 _.set(identified_packages, "python-dotenv", "*")
               }
 
+              else if ( library == "IPython" ) {
+                _.set(identified_packages, "ipython", "*")
+              }
+
+              else if ( library == "gzip" ) {
+                _.unset(identified_packages, "gzip")
+              }
+
               else {
                 _.set(identified_packages, library, "*")
               }
